@@ -190,18 +190,29 @@ void ShareUserGroupWidget::slotSharesFetched(const QList<QSharedPointer<Share>>
     layout->setContentsMargins(0, 0, 0, 0);
     int x = 0;
     int height = 0;
+    QList<QString> linkOwners({});
 
     foreach (const auto &share, shares) {
         // We don't handle link shares, only TypeUser or TypeGroup
         if (share->getShareType() == Share::TypeLink) {
+            if(!share->getUidOwner().isEmpty() &&
+                    share->getUidOwner() != share->account()->davUser()){
+                linkOwners.append(share->getOwnerDisplayName());
+             }
             continue;
         }
 
+        // the owner of the file that shared it first
+        if(x == 0 && !share->getUidOwner().isEmpty()){
+            _ui->mainOwnerLabel->setText(QString("Shared with you by ").append(share->getOwnerDisplayName()));
+        }
+
         ShareUserLine *s = new ShareUserLine(share, _maxSharingPermissions, _isFile, _parentScrollArea);
         connect(s, &ShareUserLine::resizeRequested, this, &ShareUserGroupWidget::slotAdjustScrollWidgetSize);
         connect(s, &ShareUserLine::visualDeletionDone, this, &ShareUserGroupWidget::getShares);
         s->setBackgroundRole(layout->count() % 2 == 0 ? QPalette::Base : QPalette::AlternateBase);
         layout->addWidget(s);
+        s->setVisible(true);
 
         x++;
         if (x <= 3) {
@@ -209,7 +220,18 @@ void ShareUserGroupWidget::slotSharesFetched(const QList<QSharedPointer<Share>>
         }
     }
 
-    scrollArea->setFrameShape(x > 3 ? QFrame::StyledPanel : QFrame::NoFrame);
+    foreach (const QString &owner, linkOwners) {
+        auto ownerLabel = new QLabel(QString(owner + " shared via link"));
+        layout->addWidget(ownerLabel);
+        ownerLabel->setVisible(true);
+
+        x++;
+        if (x <= 6) {
+            height = newViewPort->sizeHint().height();
+        }
+    }
+
+    scrollArea->setFrameShape(x > 6 ? QFrame::StyledPanel : QFrame::NoFrame);
     scrollArea->setVisible(!shares.isEmpty());
     scrollArea->setFixedHeight(height);
     scrollArea->setWidget(newViewPort);
@@ -420,6 +442,13 @@ ShareUserLine::ShareUserLine(QSharedPointer<Share> share,
         _permissionReshare->setVisible(false);
     }
 
+    //If the initiator is not you. And the recipient is not you. Show it without any options.
+    if(share->account()->id() != share->getId() && share->account()->davUser() != share->getShareWith()->shareWith()){
+        _ui->permissionsEdit->hide();
+        _ui->permissionToolButton->hide();
+        _ui->deleteShareButton->hide();
+    }
+
     loadAvatar();
 }
 
